sanitize_error

Function sanitize_error 

pub fn sanitize_error(e: &Error) -> String
Sanitize error messages for client responses

Logs the full error internally but returns a generic message to the client to prevent information disclosure of internal implementation details.