pub fn sanitize_error(e: &Error) -> StringExpand description
Sanitize error messages for client responses
Logs the full error internally but returns a generic message to the client to prevent information disclosure of internal implementation details.