ForwardingHandler - Handles HTTP API requests
This module receives public HTTP requests via API Gateway HTTP API, looks up the connection by subdomain, forwards the request to the agent via WebSocket, and polls for the response. If no response is received within the timeout, it returns a 504 Gateway Timeout.
Functions
- handle_
forwarding - Handler for HTTP API requests